==> web2sms_0.1.1-3.tar.gz: web2sms-0.1.1/src/providers/contacts.h <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef __web2sms_contacts_h__
#define __web2sms_contacts_h__

// Local includes
#include "contactinfo.hpp"

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

/// Convert a phone number to international format
bool make_number_international(QString& number);

extern "C"
{
  void PROVIDERS_API init_contacts();
  void PROVIDERS_API deinit_contacts();

  int PROVIDERS_API get_contact_for_sms(const QString* dialogTitle, ContactInfoList* contactList);
 
  int PROVIDERS_API add_to_sent_sms(const QString* name, const QString* number, const QString* uid, const QString* message);
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

#endif // __web2sms_contacts_h__

==> web2sms_0.1.2-2.tar.gz: web2sms-0.1.2/src/providers/contacts.h <==
/*
 *
 *  Copyright (c) 2010 Christoph Keller <gri@nospam@not-censored.com>
 *
 *  This file is part of Web2SMS.
 *
 *  Web2SMS is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  Web2SMS is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Web2SMS. If not, see <http://www.gnu.org/licenses/>
 *
 */

#ifndef __web2sms_contacts_h__
#define __web2sms_contacts_h__

// Local includes
#include "contactinfo.hpp"

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

/// Convert a phone number to international format
bool PROVIDERS_API make_number_international(QString& number);

extern "C"
{
  void PROVIDERS_API init_contacts();
  void PROVIDERS_API deinit_contacts();

  int PROVIDERS_API get_contact_for_sms(const QString* dialogTitle, ContactInfoList* contactList);
 
  int PROVIDERS_API add_to_sent_sms(const QString* name, const QString* number, const QString* uid, const QString* message);
}

//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////
//////////////////////////////////////////////////////////////////////////

#endif // __web2sms_contacts_h__
